# 【不能好好说话】不对劲的拼音首字母缩写翻译工具


大家有用过[「能不能好好说话？」 拼音首字母缩写翻译工具](https://github.com/itorr/nbnhhsh)吗？

但是它——

![./img/s.jpg](./img/s.jpg)

所以我发明了「不能好好说话」，它和「能不能好好说话？」的区别是它不能好好说话，只会说色色的话！


## 原理

其实是直接用动态规划造句啦！

首先我们根据每个词的色度给它定义1个痛苦值，越色就越不痛苦。

`f(i)`表示输入的字符串到第i个字符的最小痛苦值，其中`f(-1)=0`。

那么，假如`f(i)`的末尾的`k`个字符所组成的子串是词表中某个词的缩写，那么`f(i)`就可以从`f(i-k)`转移得到，即:

```
f(i) = min(f(i-k)+痛苦(k,i))
```

看来发明输入法还挺简单的嘛！


## 安装方法

首先你需要1个Python3.8以上版本，然后——

```
pip install git+https://github.com/RimoChan/bnhhsh.git
```

就行啦。


## 使用方法

安装好之后，你就可以——

```python
import bnhhsh
print(bnhhsh.dp('ynmm'))
```

输出:

```txt
幼女魅魔
```

幼女魅魔好耶！

## 结束

我要去和`幼女魅魔`亲热了，大家88！
